@@ -5,7 +5,7 @@ setup(name='metakernel_echo',
       version='0.19.1',
       description='A simple echo kernel for Jupyter/IPython',
       long_description='A simple echo kernel for Jupyter/IPython, based on MetaKernel',
-      url='https://github.com/calysto/metakernel/tree/master/metakernel_echo',
+      url='https://github.com/calysto/metakernel/tree/main/metakernel_echo',
       author='Douglas Blank',
       author_email='doug.blank@gmail.com',
       py_modules=['metakernel_echo'],
