@@ -5,7 +5,7 @@ setup(name='metakernel_python',
       version='0.19.1',
       description='A Python kernel for Jupyter/IPython',
       long_description='A Python kernel for Jupyter/IPython, based on MetaKernel',
-      url='https://github.com/calysto/metakernel/tree/master/metakernel_python',
+      url='https://github.com/calysto/metakernel/tree/main/metakernel_python',
       author='Douglas Blank',
       author_email='doug.blank@gmail.com',
       install_requires=['metakernel', 'jedi'],
